@@ -62,24 +62,17 @@ GdkCursor *busy_cursor = NULL;
  */
 gboolean load_graphics(GtkWidget *widget, GError **err)
 {
-#if GTK_MAJOR_VERSION >= 3
 	GtkIconTheme *icon_theme;
 
 	icon_theme = gtk_icon_theme_get_default();
-#endif
 
 	program_icon_pixbuf = gdk_pixbuf_new_from_xpm_data((const char **)sciteproj_xpm);
 
 	if (prefs.use_stock_folder_icon) {
 
 		// use GTK_STOCK_DIRECTORY
-#if GTK_MAJOR_VERSION >= 3
 		directory_closed_pixbuf = gtk_icon_theme_load_icon(icon_theme, "folder", 14, 0, NULL);
 		directory_open_pixbuf = gtk_icon_theme_load_icon(icon_theme, "folder", 14, 0, NULL);
-#else
-		directory_closed_pixbuf = gtk_widget_render_icon(widget, GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU, NULL);
-		directory_open_pixbuf = gtk_widget_render_icon(widget, GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU, NULL);
-#endif
 
 	} else {
 		directory_open_pixbuf = gdk_pixbuf_new_from_xpm_data((const char **)dir_open_xpm);
