@@ -1,7 +1,7 @@
 /**
  * gui.c - GUI code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2018 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2019 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -161,7 +161,7 @@ gboolean setup_gui(GError **err)
 	accelerator_group = gtk_accel_group_new();
 	gtk_window_add_accel_group(GTK_WINDOW(sMainWindow), accelerator_group);
 
-	if (init_menus(sMainWindow)!=0) {
+	if (init_menus(sMainWindow) != 0) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_scrolled_window_new() = NULL",
 		            __func__,
 		            "Couldn't init menus"
@@ -419,7 +419,7 @@ gboolean tree_row_is_expanded(GtkTreePath *path)
  */
 void expand_tree_row(GtkTreePath *path, gboolean expandChildren)
 {
-	if (path!=NULL) {
+	if (path != NULL) {
 		gtk_tree_view_expand_row(GTK_TREE_VIEW(projectTreeView), path, FALSE);
 	}
 }
@@ -546,10 +546,16 @@ static void tree_row_activated_cb(GtkTreeView *treeView,
 EXITPOINT:
 
 	if (err != NULL) {
+
+		gchar *could_not_open_string;
+		could_not_open_string = g_strdup_printf(_("Could not open selected file:"));
+
 		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-		                                _("Could not open selected file: \n\n%s"), err->message);
+		                                _("%s\n\n%s"), could_not_open_string, err->message);
 
 		gtk_dialog_run(GTK_DIALOG (dialog));
+
+		g_free(could_not_open_string);
 	}
 
 	if (relFilePath) g_free(relFilePath);
@@ -584,7 +590,7 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 
 	// Until we know for sure, assume that the user has not clicked on a node
 
-	clicked_node.valid=FALSE;
+	clicked_node.valid = FALSE;
 
 
 	// If it is not a right-click, then ignore it
@@ -599,11 +605,6 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 	                                   (gint) event->x, (gint) event->y,
 	                                   &path, NULL, NULL, NULL)) {
 		// Nope-- user clicked in the GtkTreeView, but not on a node
-
-		if (generalPopupMenu) {
-			gtk_menu_popup_at_pointer(GTK_MENU(generalPopupMenu), (GdkEvent*)event);													
-		}
-													  
 		goto EXITPOINT;
 	}
 
@@ -631,7 +632,7 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 	// Check if something is selected
 	tree_selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeView));
 
-	if (tree_selection!=NULL) {
+	if (tree_selection != NULL) {
 		// Check if clicked on something in the selection, otherwise make the clicked one the selection.
 
 		if (gtk_tree_selection_path_is_selected(tree_selection, path) == FALSE) {
