@@ -58,11 +58,7 @@ gboolean init_statusbar(GtkWidget *widget, GtkWidget *next_to, GError **err)
 
 	gtk_widget_set_size_request(statusbar, -1, 20);
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_grid_attach_next_to(GTK_GRID(widget), statusbar, next_to, GTK_POS_BOTTOM, 1, 1);
-#else
-	gtk_box_pack_end (GTK_BOX (widget), statusbar, FALSE, FALSE, 0);
-#endif
 
 	gtk_widget_show (statusbar);
 
